mobileBaseVelocityControl {#master}
-----------

Important Changes
-----------------

### devices

* added the following new devices: `MobileBaseVelocityControl_nwc_yarp` , `MobileBaseVelocityControl_nws_yarp` , `MobileBaseVelocityControl_nws_ros`

